# Image Keyword Tool

[![pypi](https://img.shields.io/pypi/v/ikt.svg)](https://pypi.python.org/pypi/ikt)
[![python](https://img.shields.io/pypi/pyversions/ikt.svg)](https://pypi.python.org/pypi/ikt)
[![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/insspb/ikt/Run%20checks/master)](https://github.com/insspb/ikt)
[![docs](https://readthedocs.org/projects/ikt/badge/?version=latest)](https://ikt.readthedocs.io/en/latest/?badge=latest)
[![Code Qaulity](https://img.shields.io/scrutinizer/g/insspb/ikt.svg)](https://scrutinizer-ci.com/g/insspb/ikt/?branch=master)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

Image Keyword Tool (IKT) is command-line utility that simplify usage of deep
learning libraries for image tags generation.

This tool is in active development. Most futures only in planned state now.

## Features

* Python 3.7+ only
* Linux, Mac and Windows support
* [planned] JPG images recognition and tagging
* [planned] Convert PNG images to JPG images for tagging
* [planned] Write tags to JPGs exif
* [planned] Write tags to separate txt files
* [planned] Recognition threshold configuration
* [planned] Pluggable and selectable IA modules
* [planned] Pluggable modules for stock sites upload

## Installation

```bash
pip install ikt
```

## Usage instructions

```bash
ikt --help
```

## Documentation

Check out the [documentation](https://ikt.readthedocs.io/en/latest/) for more
info.

## Contributions

Contributions are very welcome. Please check
[contributors Guide](CONTRIBUTING.md).

## Code of Conduct

Everyone interacting in the Image Keywords tools project's codebases, issue
trackers, chat rooms, and mailing lists is expected to follow the
[Code of Conduct](CODE_OF_CONDUCT.md).

## License

MIT License

See [LICENSE](https://github.com/insspb/ikt/blob/master/LICENSE) to see the full
text.
